searchData={"items":[{"type":"protocol","title":"Omnipresence","doc":"A protocol for presence checking. This is intended to be imported when\nnecessary.","ref":"Omnipresence.html"},{"type":"protocol","title":"Implementing - Omnipresence","doc":"If you have a struct that you wish to have custom presence check for, you can\nimplement it rather quickly.\n\n```elixir\ndefmodule Dog do\n  defstruct [:name, :age]\nend\n\ndefimpl Omnipresence, for: Dog do\n  def present?(%Dog{name: nil, age: nil}), do: false\n  def present?(_), do: true\n\n  def blank?(dog), do: !present?(dog)\n\n  def presence(%Dog{name: nil, age: nil}), do: nil\n  def presence(dog), do: dog\nend\n```","ref":"Omnipresence.html#module-implementing"},{"type":"protocol","title":"Examples - Omnipresence","doc":"```elixir\nimport Omnipresence\n\nif present?(calculated_value()) do\n  IO.puts(\"I'm present\")\nelse\n  IO.puts(\"I'm blank\")\nend\n\nif blank?(nil) do\n  IO.puts(\"I'm blank\")\nend\n```\n\n```elixir\nraw_value\n|> some_function()\n|> Stream.map(&Omnipresence.presence/1)\n|> Stream.reject(&is_nil/1)\n|> Enum.each(fn value ->\n  IO.inspect(value)\nend)\n```\n\n```elixir\nassert presence(\" \") == nil\n```","ref":"Omnipresence.html#module-examples"},{"type":"function","title":"Omnipresence.blank?/1","doc":"","ref":"Omnipresence.html#blank?/1"},{"type":"function","title":"Omnipresence.presence/1","doc":"","ref":"Omnipresence.html#presence/1"},{"type":"function","title":"Omnipresence.present?/1","doc":"Check if a value is present","ref":"Omnipresence.html#present?/1"},{"type":"type","title":"Omnipresence.t/0","doc":"All the types that implement this protocol.","ref":"Omnipresence.html#t:t/0"},{"type":"extras","title":"Readme","doc":"# Omnipresence\n\nYet another presence checker for elixir.","ref":"readme.html"},{"type":"extras","title":"Installation - Readme","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `omnipresence` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:omnipresence, \"~> 1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Readme","doc":"```elixir\nimport Omnipresence\n\nif present?(calculated_value()) do\n  IO.puts(\"I'm present\")\nelse\n  IO.puts(\"I'm blank\")\nend\n\nif blank?(nil) do\n  IO.puts(\"I'm blank\")\nend\n```\n\n```elixir\nraw_value\n|> some_function()\n|> Stream.map(&Omnipresence.presence/1)\n|> Stream.reject(&is_nil/1)\n|> Enum.each(fn value ->\n  IO.inspect(value)\nend)\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#usage"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n# v1.0.0\n- Added more property tests\n- Bump minimum elixir to `1.13`\n\n# v0.1.0\n- Initial release","ref":"changelog.html"}],"content_type":"text/markdown"}